@@ -11,10 +11,10 @@
 #undef DEBUG
 
 /* Define if you have the bz2 library (-lbz2).  */
-#define HAVE_LIBBZ2 1
+#undef HAVE_LIBBZ2
 
 /* Define if you have the z library (-lz).  */
-#define HAVE_LIBZ 1
+#undef HAVE_LIBZ
 
 /* Define if you have the compress2 function.  */
 #undef HAVE_COMPRESS2
