@@ -1,7 +1,7 @@
 #include "dact.h"
 #include "config.h"
 
-#if defined(USE_MODULES) && defined(COMP_BZLIB_IS_MOD) && !defined(AS_MODULE)
+#if defined(USE_MODULES) && !defined(AS_MODULE)
 #define comp_bzlib_algo DACT_FAILED_ALGO
 #else
 int comp_bzlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
