@@ -69,8 +69,8 @@ int comp_mzlib2_algo(int mode, unsigned char *prev_block, unsigned char *curr_bl
 int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	unsigned long dest_size;
 	unsigned char *tmp_block;
-	FOUR_BYTES freq[SQRD_256];
-	TWO_BYTES lookup_table[SQRD_256], curr_val, repl_val;
+	uint32_t freq[SQRD_256];
+	uint16_t lookup_table[SQRD_256], curr_val, repl_val;
 	int i, cnt, m=2, retval, low_byte=0;
 
 	memset(freq,0,sizeof(freq));
@@ -82,7 +82,7 @@ int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, c
 		if (freq[i]!=0) fprintf(stderr, "%04x: 0x%02x and 0x%02x are near each other %i times\n",i,i>>8,i&0xff,freq[i]);
 */
 
-	int_sort_fast(freq, SQRD_256);
+	int_sort_fast(freq, SQRD_256, 0);
 
 	for (i=0;i<(SQRD_256);i++) {
 		if ((freq[i]&0xffff)!=0) {
@@ -90,7 +90,7 @@ int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, c
 			out_block[m++]=(freq[i]>>16)&0xff;
 			if (m>=(DACT_BLK_SIZE*2)) return(-1);
 			lookup_table[freq[i]>>16]=i;
-//			fprintf(stderr, "%04x: 0x%02x and 0x%02x are near each other %i times\n",i,(freq[i]>>24),(freq[i]>>16)&0xff,freq[i]&0xffff);
+/*			fprintf(stderr, "%04x: 0x%02x and 0x%02x are near each other %i times\n",i,(freq[i]>>24),(freq[i]>>16)&0xff,freq[i]&0xffff); */
 		} else {
 			break;
 		}
@@ -111,7 +111,9 @@ int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, c
 	}
 
 	dest_size=(int) ((float) ((m*1.02)+15));
-        tmp_block=malloc(dest_size);
+	if ((tmp_block=malloc(dest_size))==NULL) {
+		return(-1);
+	}
         memcpy(tmp_block,out_block,m);
 /*
 	for (i=0;i<m;i++) {
@@ -122,8 +124,10 @@ int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, c
 	printf("\n\n");
 */
 
-//	for (i=0;i<blk_size;i++) printf("%02x ", curr_block[i]);
-//	printf("\n");
+/*
+	for (i=0;i<blk_size;i++) printf("%02x ", curr_block[i]);
+	printf("\n");
+*/
 
 	retval=compress(out_block, &dest_size, tmp_block, m);
 	if (retval!=Z_OK) {
@@ -135,7 +139,7 @@ int comp_mzlib2_compress(unsigned char *prev_block, unsigned char *curr_block, c
 }
 
 int comp_mzlib2_decompress(unsigned char *prev_block, unsigned char *curr_block, unsigned char *out_block, int blk_size) {
-	TWO_BYTES lookup_table[SQRD_256], curr_val, repl_val;
+	uint16_t lookup_table[SQRD_256], curr_val, repl_val;
 	unsigned long dest_size=(DACT_BLK_SIZE*2);
 	unsigned char *tmp_block;
 	unsigned int m=0, hdrsize;
@@ -165,8 +169,10 @@ int comp_mzlib2_decompress(unsigned char *prev_block, unsigned char *curr_block,
 		out_block[m++]=repl_val&0xff;
 	}
 
-//        for (i=0;i<m;i++) printf("%02x ", out_block[i]);
-//        printf("\n");
+/*
+	for (i=0;i<m;i++) printf("%02x ", out_block[i]);
+	printf("\n");
+*/
 
 	free(tmp_block);
 	return(m);
