@@ -3,8 +3,12 @@
 MACHINE=`uname -m | sed s/"i.86"/"i386"/ | dd conv=lcase 2>/dev/null`
 OS=`uname -s | dd conv=lcase 2>/dev/null`
 FILE="http://www.rkeene.org/devel/dact/precompiled/dact-$MACHINE-$OS.bin"
-LFILE="dact-$MACHINE-$OS"
+LFILE="dact-$MACHINE-$OS.bin"
 
+if [ "$1" = "detcomp" ]; then
+  echo $LFILE
+  exit
+fi
 
 
 if which lynx 2>/dev/null >/dev/null; then
@@ -18,13 +22,13 @@ else
   exit 1
 fi
 
-if [ -e $LFILE ]; then
+if [ -f $LFILE ]; then
  if head -2 $LFILE | grep "Not Found" 2>/dev/null >/dev/null; then
    rm $LFILE
  fi 
 fi
 
-if [ ! -e $LFILE ]; then
+if [ ! -f $LFILE ]; then
   echo "Unable to find an appropriate precompiled binary for a $MACHINE running $OS"
   echo "Contact Roy Keene <rkeene@rkeene.org> if you need further assistance."
   echo "The latest dact source can be found at:"
