@@ -170,7 +170,7 @@ uint32_t dact_blk_decompress(char *ret, const char *srcbuf, const uint32_t size,
 uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint32_t size, const char *options) {
 	char *tmpbuf, *smallbuf=NULL;
 	int i, highest_algo=0;
-	int smallest_algo;
+	char smallest_algo;
 	uint32_t smallest_size=-1, x;
 
 	if ((tmpbuf=malloc(size*2))==NULL) { PERROR("malloc"); return(0); }
@@ -198,7 +198,7 @@ uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint
 	}
 
 	free(tmpbuf);
-	memcpy(algo, &smallest_algo, sizeof(int));
+	memcpy(algo, &smallest_algo, sizeof(char));
 	memcpy(ret, smallbuf, smallest_size);
 	return(smallest_size);
 }
