@@ -42,10 +42,10 @@ int createconnection_tcp(char *host, int port) {
 	struct hostent *hostinfo;
 	struct sockaddr_in sock;
 	if ((hostinfo=gethostbyname(host))==NULL) {
-#ifdef USE_ADDR
-		if ( (sock.sin_addr.s_addr=inet_addr(host) )==-1)
-#else
+#ifdef HAVE_INET_ATON
 		if (!inet_aton(host,&sock.sin_addr))
+#else
+		if ( (sock.sin_addr.s_addr=inet_addr(host) )==-1)
 #endif
 			return(-1);
 	} else {
